==> openGion6.6.0.1_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE31S.sql <==
/****************************************************************************/
/* GE31 ( 定型文ﾏｽﾀ )                                                       */
/*                                                                          */
/* Created : 2016/10/27 10:57:15                                            */
/****************************************************************************/

CREATE TABLE GE31 (
   SYSTEM_ID    varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID       */
 , PTN_ID       varchar           (   20 )                  NOT NULL            /*  20 定型文ID     */
 , FROM_ID      varchar           (   50 )                                      /*  30 送信者ID     */
 , TO_ID        varchar           ( 4000 )                                      /*  40 宛先(TO)     */
 , CC_ID        varchar           ( 4000 )                                      /*  50 宛先(CC)     */
 , BCC_ID       varchar           ( 4000 )                                      /*  60 宛先(BCC)    */
 , TITLE        varchar           (  300 )                  NOT NULL            /*  70 ﾀｲﾄﾙ         */
 , CONTENTS     varchar           ( 4000 )                                      /*  80 内容         */
 , JOKEN        varchar           (   20 )                                      /*  85 振分条件     */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          varchar           (    1 )      DEFAULT 1   NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar           (   14 )                                      /* 820 登録日時     */
 , PGSET        varchar           (   10 )                                      /* 830 作成PG       */
 , PGPSET       varchar           (   10 )                                      /* 840 作成親PG     */
 , USRSET       varchar           (   10 )                                      /* 850 作成社員     */
 , DYUPD        varchar           (   14 )                                      /* 860 更新日時     */
 , PGUPD        varchar           (   10 )                                      /* 870 更新PG       */
 , PGPUPD       varchar           (   10 )                                      /* 880 更新親PG     */
 , USRUPD       varchar           (   10 )                                      /* 890 更新者       */
);

==> openGion7.2.6.1_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE31S.sql <==
/****************************************************************************/
/* GE31 ( 定型文ﾏｽﾀ )                                                       */
/*                                                                          */
/* Created : 2018/09/28 16:03:40                                            */
/****************************************************************************/

CREATE TABLE GE31 (
   SYSTEM_ID    varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID       */
 , PTN_ID       varchar           (   20 )                  NOT NULL            /*  20 定型文ID     */
 , FROM_ID      varchar           (   50 )                                      /*  30 送信者ID     */
 , TO_ID        varchar           ( 4000 )                                      /*  40 宛先(TO)     */
 , CC_ID        varchar           ( 4000 )                                      /*  50 宛先(CC)     */
 , BCC_ID       varchar           ( 4000 )                                      /*  60 宛先(BCC)    */
 , TITLE        varchar           (  300 )                  NOT NULL            /*  70 ﾀｲﾄﾙ         */
 , CONTENTS     varchar           ( 4000 )                                      /*  80 内容         */
 , JOKEN        varchar           (   20 )                                      /*  85 振分条件     */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          varchar           (    1 )      DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar           (   14 )                                      /* 820 登録日時     */
 , PGSET        varchar           (   10 )                                      /* 830 作成PG       */
 , PGPSET       varchar           (   10 )                                      /* 840 作成親PG     */
 , USRSET       varchar           (   10 )                                      /* 850 作成者       */
 , DYUPD        varchar           (   14 )                                      /* 860 更新日時     */
 , PGUPD        varchar           (   10 )                                      /* 870 更新PG       */
 , PGPUPD       varchar           (   10 )                                      /* 880 更新親PG     */
 , USRUPD       varchar           (   10 )                                      /* 890 更新者       */
);
